@@ -1,7 +1,24 @@
 """Plotting functions."""
+
+# Copyright (C) 2021  Blue Brain Project, EPFL
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 import logging
 import multiprocessing
 import os
+from copy import copy
 from functools import partial
 from pathlib import Path
 
@@ -14,6 +31,7 @@ from matplotlib.backends.backend_pdf import PdfPages
 from neurom import APICAL_DENDRITE
 from neurom import AXON
 from neurom import BASAL_DENDRITE
+from neurom import COLS
 from neurom import get
 from neurom import iter_sections
 from neurom.geom import bounding_box
@@ -31,57 +49,13 @@ L = logging.getLogger(__name__)
 COLORS = {"basal": "r", "apical": "m", "axon": "b"}
 
 CUMULATIVE_FEATURE_PAIRS = [
-    #    ("section_radial_distances", "section_volumes"),
-    #    ("section_radial_distances", "section_areas"),
     ("section_path_distances", "section_volumes"),
     ("section_path_distances", "section_areas"),
-    #    ("section_branch_orders", "section_volumes"),
-    #    ("section_branch_orders", "section_areas"),
 ]
 
-VIOLIN_FEATURES_LIST = [
-    "segment_radii",
-    "section_areas",
-    "section_volumes",
-    #    "sibling_ratio",
-    #    "diameter_power_relation",
-]
+VIOLIN_FEATURES_LIST = ["segment_radii", "section_areas", "section_volumes"]
 
-# to include morphologies only features
-VIOLIN_FEATURES_LIST += [
-    "number_of_neurites",
-    "number_of_sections_per_neurite",
-    "number_of_leaves",
-    "number_of_bifurcations",
-    "section_lengths",
-    "section_tortuosity",
-    "section_radial_distances",
-    "section_path_distances",
-    "section_branch_orders",
-    "remote_bifurcation_angles",
-]
-
-VIOLIN_FEATURES_NAME = [
-    "Segment radii",
-    "Section areas",
-    "Section volumes",
-    #    "Sibling ratios",
-    #    "Diameter power relation",
-]
-
-# to include morphologies only features
-VIOLIN_FEATURES_NAME += [
-    "Number of neurites",
-    "Number of sections",
-    "Number of terminations",
-    "Number of bifurcations",
-    "Section lengths",
-    "Section tortuosity",
-    "Section radial distances",
-    "Section path distances",
-    "Section branch orders",
-    "Remote bif angles",
-]
+VIOLIN_FEATURES_NAME = ["Segment radii", "Section areas", "Section volumes"]
 
 NEURITE_STR_TO_TYPES = {
     "basal": nm.NeuriteType.basal_dendrite,
@@ -117,26 +91,27 @@ def _compute_neurite_diff(neuron_orig, neuron_new, neuron_diff_pos, neuron_diff_
         for neurite_orig, neurite_new, neurite_diff_pos, neurite_diff_neg in zip(
             neurites_orig, neurites_new, neurites_diff_pos, neurites_diff_neg
         ):
-            diam_orig = []
-            diam_new = []
+            orig = []
+            new = []
             for section_orig, section_new in zip(
                 iter_sections(neurite_orig), iter_sections(neurite_new)
             ):
-                # pylint: disable=protected-access
-                diam_orig.append(utils._get_diameters(section_orig))
-                diam_new.append(utils._get_diameters(section_new))
+                orig.append(section_orig.points)
+                new.append(section_new.points)
 
             for j, section in enumerate(iter_sections(neurite_diff_pos)):
-                diff = diam_new[j] - diam_orig[j]
-                diff_pos = diff.copy()
-                diff_pos[diff_pos < 0] = 0
-                section.points[:, nm.COLS.R] = diff_pos
+                _diff = new[j][:, COLS.R] - orig[j][:, COLS.R]
+                _diff[_diff < 0] = 0
+                diff = copy(orig[j])
+                diff[:, COLS.R] = _diff
+                section.points = diff
 
             for j, section in enumerate(iter_sections(neurite_diff_neg)):
-                diff = diam_new[j] - diam_orig[j]
-                diff_neg = -diff.copy()
-                diff_neg[diff_neg < 0] = 0
-                section.points[:, nm.COLS.R] = diff_neg
+                _diff = -(new[j][:, COLS.R] - orig[j][:, COLS.R])
+                _diff[_diff < 0] = 0
+                diff = copy(orig[j])
+                diff[:, COLS.R] = _diff
+                section.points = diff
 
 
 def plot_diameter_diff(neuron_name, neuron_new, neurite_types, folder, ext=".png"):
@@ -328,20 +303,16 @@ def plot_cumulative_distribution(
 ):
     """Plot the cumulative distribution of features.
 
-    It plots feature2 with respect to
-    the metric values determined via feature1.
+    It plots feature2 with respect to the metric values determined via feature1.
 
     Args:
-        original_cells: list of NeuroM objects
-        diametrized_cells: list of NeuroM objects
-            The new cells with the changed diameters.
-        feature1: the metric feature
-        feature2: the cumulative distribution feature
-        neurite_types: string
-            The list neurite types to be considered. e.g. ['basal', 'axon']
-        step_size: float
-            The step size of the cumulative histogram
-        auto_limit: automatically compute limits
+        original_cells: list of NeuroM objects.
+        diametrized_cells (list): The new cells with the changed diameters.
+        feature1: the metric feature.
+        feature2: the cumulative distribution feature.
+        neurite_types (string): The list neurite types to be considered. e.g. ['basal', 'axon'].
+        step_size (float): The step size of the cumulative histogram.
+        auto_limit (bool): automatically compute limits.
 
     Examples of metric features (feature1):
         - segment_radial_distances
@@ -479,8 +450,7 @@ def make_cumulative_figures(
     )
 
     figure_name = f"{figname_prefix}cumulative_{prefix1}_{basename1}_{basename2}"
-
-    fig.savefig(out_dir / (figure_name + ext), bbox_inches="tight")
+    fig.savefig(out_dir / f"{figure_name}{ext}", bbox_inches="tight")
     plt.close(fig)
 
     if individual:
