@@ -1,4 +1,20 @@
 """Test the cli module."""
+
+# Copyright (C) 2021  Blue Brain Project, EPFL
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 import json
 from pathlib import Path
 
@@ -23,7 +39,7 @@ def test_run_models(tmpdir, single_pop_data_dir, single_pop_diametrized_data_dir
     extract_models_params["neurite_types"] = ["basal", "apical"]
 
     config_file = str(tmpdir / "diametrizer_params.json")
-    with open(config_file, "w") as json_file:
+    with open(config_file, "w", encoding="utf-8") as json_file:
         json.dump(extract_models_params, json_file, sort_keys=True, indent=4)
 
     # Run with CLI
@@ -31,7 +47,7 @@ def test_run_models(tmpdir, single_pop_data_dir, single_pop_diametrized_data_dir
     runner.invoke(cli.cli, ["run_models", config_file], catch_exceptions=False)
 
     # Check results
-    with open(extract_models_params["models_params_file"], "r") as json_file:
+    with open(extract_models_params["models_params_file"], "r", encoding="utf-8") as json_file:
         res = json.load(json_file)
 
     assert list(res.keys()) == ["generic"]
@@ -82,7 +98,7 @@ def test_run_diameters(tmpdir, single_pop_data_dir, config, model_params_path):
     extract_models_params["new_morph_path"] = str(res_path)
 
     config_file = str(tmpdir / "diametrizer_params.json")
-    with open(config_file, "w") as json_file:
+    with open(config_file, "w", encoding="utf-8") as json_file:
         json.dump(extract_models_params, json_file, sort_keys=True, indent=4)
 
     # Run with CLI
@@ -105,8 +121,11 @@ def test_plot_diff(tmpdir, single_pop_data_dir, single_pop_diametrized_data_dir)
         cli.cli,
         [
             "plot_diff",
+            "--orig-path",
             str(single_pop_data_dir),
+            "--diam-path",
             str(single_pop_diametrized_data_dir),
+            "--out-dir",
             str(res_path),
             "--ext",
             ".pdf",
@@ -115,7 +134,7 @@ def test_plot_diff(tmpdir, single_pop_data_dir, single_pop_diametrized_data_dir)
     )
 
     # Check results
-    assert [i.name for i in (res_path / "generic_type").iterdir()] == ["C030796A-P3_lite.pdf"]
+    assert [i.name for i in (res_path / "diffs").iterdir()] == ["C030796A-P3_lite.pdf"]
 
 
 def test_run_analysis(tmpdir, single_pop_data_dir, single_pop_diametrized_data_dir):
